require Libtool::Compile;
require Libtool::Link;
require Libtool::Clean;
require Libtool::Execute;
require Libtool::Finish;
require Libtool::Install;
require Libtool::Uninstall;

@args = ();
@toolargs = ();
@modeargs = ();
$tool = undef;


$do_show_config = undef;
$do_debug = undef;
$do_dry_run = undef;
$do_features = undef;
$do_show_help = undef;
$do_be_silent = undef;
$do_show_version = undef;
$do_clean = undef;
$do_compile = undef;
$do_execute = undef;
$do_finish = undef;
$do_install = undef;
$do_link = undef;
$do_uninstall = undef;


## detect mode=???? and other primary arguments
while ( $#ARGV >= 0 )
  {
  push @args, $ARGV[0];
  if ($ARGV[0] =~ /--mode=(.*)/)
    {
      my $mode = $1;
      if($mode =~ 'clean')
        {
        $do_clean = 1;
        }
      elsif($mode =~ 'compile')
        {
        $do_compile = 1;
        }
      elsif($mode =~ 'execute')
        {
        $do_execute = 1;
        }
      elsif($mode =~ 'finish')
        {
        $do_finish = 1;
        }
      elsif($mode =~ 'install')
        {
        $do_install = 1;
        }
      elsif($mode =~ 'link')
        {
        $do_link = 1;
        }
      elsif($mode =~ 'uninstall')
        {
        $do_uninstall = 1;
        }
    }
  elsif ($ARGV[0] =~ '--config')
    {
    $do_show_config = 1;
    }
  elsif ($ARGV[0] =~ '--debug')
    {
    $do_debug = 1;
    }
  elsif ($ARGV[0] =~ '--dry-run')
    {
    $do_dry_run = 1;
    }
  elsif ($ARGV[0] =~ '-n')
    {
    $do_dry_run = 1;
    }
  elsif ($ARGV[0] =~ '--features')
    {
    $do_features = 1;
    }
  elsif ($ARGV[0] =~ '--finish')
    {
    $do_finish = 1;
    }
  elsif ($ARGV[0] =~ '--help')
    {
    $do_show_help = 1;
    }
  elsif ($ARGV[0] =~ '--quiet')
    {
    $do_be_silent = 1;
    }
  elsif ($ARGV[0] =~ '--silent')
    {
    $do_be_silent = 1;
    }
  elsif ($ARGV[0] =~ '--version')
    {
    $do_show_version = 1;
    }
  else
    {
    push @modeargs, $ARGV[0];
    }
  
  shift
  }
  
# at this point we should have some notion of what we're supposed to do
if ($do_show_help)
  {
  libtool_show_help();
  }
elsif ($do_show_version)
  {
  libtool_show_version();
  }
elsif($do_show_config)
  {
  libtool_show_version();
  }
elsif($do_features)
  {
  libtool_features();
  }
elsif($do_clean)
  {
  libtool_clean(@modeargs);
  }
elsif($do_compile)
  {
  libtool_compile(@modeargs);
  }
elsif($do_execute)
  {
  libtool_execute(@modeargs);
  }
elsif($do_finish)
  {
  libtool_finish(@modeargs);
  }
elsif($do_install)
  {
  libtool_install(@modeargs);
  }
elsif($do_link)
  {
  libtool_link(@modeargs);
  }
elsif($do_uninstall)
  {
  libtool_uninstall(@modeargs);
  }


sub libtool_clean
  {
  Libtool::Clean::execute(@_);
  }

sub libtool_compile
  {
  Libtool::Compile::execute(@_);
  }

sub libtool_execute
  {
  Libtool::Execute::execute(@_);
  }


sub libtool_finish
  {
  Libtool::Finish::execute(@_);
  }

sub libtool_install
  {
  Libtool::Install::execute(@_);
  }

sub libtool_link
  {
  Libtool::Link::execute(@_);
  }

sub libtool_uninstall
  {
  Libtool::Uninstall::execute(@_);
  }
  
sub libtool_show_help
  {
  if($do_clean)
    {

    }
  elsif($do_compile)
    {

    }
  elsif($do_execute)
    {

    }
  elsif($do_finish)
    {

    }
  elsif($do_install)
    {

    }
  elsif($do_link)
    {

    }
  elsif($do_uninstall)
    {

    }
  else
    {
    print "Usage: libtool [OPTION]... [MODE-ARG]...\n";
    print "\n";
    print "Provide generalized library-building support services.\n";
    print "\n";
    print "    --config          show all configuration variables\n";
    print "    --debug           enable verbose shell tracing\n";
    print "-n, --dry-run         display commands without modifying any files\n";
    print "    --features        display basic configuration information and exit\n";
    print "    --finish          same as `--mode=finish'\n";
    print "    --help            display this help message and exit\n";
    print "    --mode=MODE       use operation mode MODE [default=inferred from MODE-ARGS]\n";
    print "    --quiet           same as `--silent'\n";
    print "    --silent          don't print informational messages\n";
    print "    --version         print version information\n";
    print "\n";
    print "MODE must be one of the following:\n";
    print "\n";
    print "      clean           remove files from the build directory\n";
    print "      compile         compile a source file into a libtool object\n";
    print "      execute         automatically set library path, then run a program\n";
    print "      finish          complete the installation of libtool libraries\n";
    print "      install         install libraries or executables\n";
    print "      link            create a library or an executable\n";
    print "      uninstall       remove libraries from an installed directory\n";
    print "\n";
    print "MODE-ARGS vary depending on the MODE.  Try `libtool --help --mode=MODE' for\n";
    print "a more detailed description of MODE.\n";
    }
  }


sub libtool_show_version
  {
  
  }

sub libtool_show_version
  {
  
  }
sub libtool_features
  {
  
  }
  
  
sub load_lo_file
  {
  
  }
  
sub load_la_file
  {
  
  }
    
sub write_lo_file
  {

  }

sub write_la_file
  {

  }



